Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(14)

Unified Diff: ui/compositor/layer_animation_sequence.h

Issue 12226080: Thread ui transform animations (Closed) Base URL: http://git.chromium.org/chromium/src.git@DefineThreadedLayerAnimationElements
Patch Set: Speed up animations in WebContentsViewAuraTest.QuickOverscrollDirectionChange Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/compositor/layer_animation_element_unittest.cc ('k') | ui/compositor/layer_animation_sequence.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/compositor/layer_animation_sequence.h
diff --git a/ui/compositor/layer_animation_sequence.h b/ui/compositor/layer_animation_sequence.h
index 6f7c96e7438cef4b5a1156a73ea03f26fe22d8b8..2f2e405ef36db7668a4fc2abd37442c6fcfb6cfd 100644
--- a/ui/compositor/layer_animation_sequence.h
+++ b/ui/compositor/layer_animation_sequence.h
@@ -93,9 +93,9 @@ class COMPOSITOR_EXPORT LayerAnimationSequence
void set_is_cyclic(bool is_cyclic) { is_cyclic_ = is_cyclic; }
bool is_cyclic() const { return is_cyclic_; }
// Returns true if this sequence has at least one element affecting a
// property in |other|.
- bool HasCommonProperty(
+ bool HasConflictingProperty(
const LayerAnimationElement::AnimatableProperties& other) const;
// Returns true if the first element animates on the compositor thread.
« no previous file with comments | « ui/compositor/layer_animation_element_unittest.cc ('k') | ui/compositor/layer_animation_sequence.cc » ('j') | no next file with comments »
@@ -93,9 +93,9 @@ class COMPOSITOR_EXPORT LayerAnimationSequence
void set_is_cyclic(bool is_cyclic) { is_cyclic_ = is_cyclic; }
bool is_cyclic() const { return is_cyclic_; }
- // Returns true if this sequence has at least one element affecting a
+ // Returns true if this sequence has at least one element conflicting with a
// property in |other|.

Powered by Google App Engine
This is Rietveld 408576698